(function($, Drupal, document) {
  'use strict';

  Drupal.AmazonLPA = {
    merchantId: '',
    authRequest: '',
    clientId: '',
    checkoutUrl: '',
    langcode: '',
    orderReferenceId: '',
    loginButtonOptions: {
      style: 'Gold',
      size: 'medium',
      type: 'LwA'
    },
    loginOptions: {
      scope: 'profile postal_code payments:widget payments:shipping_address',
      popup: true
    },
    payButtonOptions: {
      style: 'Gold',
      size: 'medium',
      type: 'PwA'
    },
    addressBookOptions: {
      displayMode: 'edit'
    },
    walletOptions: {
      displayMode: 'edit'
    },

    errorHandler: function (f) {
      console.log(f.getErrorCode()+f.getErrorMessage())
    },

    LoginButton: function (elId) {
      if (document.getElementById(elId) !== null) {
        var $el = $('#' + elId);
        OffAmazonPayments.Button(elId, Drupal.AmazonLPA.merchantId, {
          type: $el.data('pay-type'),
          color: Drupal.AmazonLPA.loginButtonOptions.style,
          size: $el.data('pay-size'),
          language: Drupal.AmazonLPA.langcode,
          useAmazonAddressBook: true,
          authorization: function () {
            var loginOptions = Drupal.AmazonLPA.loginOptions;
            Drupal.AmazonLPA.authRequest = amazon.Login.authorize(loginOptions, $el.data('url'));
          },
          onError: function (error) {
            Drupal.AmazonLPA.errorHandler(error);
          }
        });
      }
    },

    PaymentButton: function (elId) {
      if (document.getElementById(elId) !== null) {
        var $el = $('#' + elId);
        OffAmazonPayments.Button(elId, Drupal.AmazonLPA.merchantId, {
          type: $el.data('pay-type'),
          color: Drupal.AmazonLPA.payButtonOptions.style,
          size: $el.data('pay-size'),
          language: Drupal.AmazonLPA.langcode,
          useAmazonAddressBook: true,
          authorization: function () {
            var loginOptions = Drupal.AmazonLPA.loginOptions;
            Drupal.AmazonLPA.authRequest = amazon.Login.authorize(loginOptions, $el.data('checkout-url'));
          },
          onError: function (error) {
            Drupal.AmazonLPA.errorHandler(error);
          }
        });
      }
    },

    AddressBookWidget: function (elId) {
      new OffAmazonPayments.Widgets.AddressBook({
        sellerId: Drupal.AmazonLPA.merchantId,
        displayMode: Drupal.AmazonLPA.addressBookOptions.displayMode,
        design: {
          designMode: 'responsive'
        },
        /**
         * Provide a way to return the current order's contract ID.
         *
         * @see c.Widgets.AddressBook.prototype.renderAddressBook
         *
         * @returns string|null
           */
        getContractId: function () {
          if (Drupal.AmazonLPA.orderReferenceId) {
            console.log("Reused order reference ID: " + Drupal.AmazonLPA.orderReferenceId);
            return Drupal.AmazonLPA.orderReferenceId;
          }

          return null;
        },
        onOrderReferenceCreate: function (orderReference) {
          if (!Drupal.AmazonLPA.orderReferenceId) {
            Drupal.AmazonLPA.orderReferenceId = orderReference.getAmazonOrderReferenceId();
            console.log("Generated order reference ID: " + Drupal.AmazonLPA.orderReferenceId);
            var $referenceIdField = $('input[name="commerce_amazon_lpa_contract_id[reference_id]"]', document);
            if ($referenceIdField.length > 0) {
              console.log("Generated saved order reference ID: " + Drupal.AmazonLPA.orderReferenceId);
              $referenceIdField.val(orderReference.getAmazonOrderReferenceId());
            }
          }
        },
        onAddressSelect: function (orderReference) {
          // Support check forms with shipping pane inline and AJAX.
          if (typeof $.fn.commerceCheckShippingRecalculation == 'function') {
            $.fn.commerceCheckShippingRecalculation();
          }
        },
        onError: function (error) {
          Drupal.AmazonLPA.errorHandler(error);
          console.log(error);
        }
      }).bind(elId);
    },

    WalletWidget: function (elId) {
      new OffAmazonPayments.Widgets.Wallet({
        sellerId: Drupal.AmazonLPA.merchantId,
        amazonOrderReferenceId: Drupal.AmazonLPA.orderReferenceId,
        onPaymentSelect: function () {

        },
        onOrderReferenceCreate: function(orderReference) {
          // Use the following cod to get the generated Order Reference ID.
          var $referenceIdField = $('input[name="commerce_payment[payment_details][amazon_order_reference_id]"]', document);
          if ($referenceIdField.length > 0 && $referenceIdField.val() == 0) {
            $referenceIdField.val(orderReference.getAmazonOrderReferenceId());
          }
        },
        design: {
          designMode: 'responsive'
        },
        onError: function (error) {
          Drupal.AmazonLPA.errorHandler(error);
        }
      }).bind(elId);
    }
  };

  Drupal.behaviors.commerceAmazonLPA = {
    attach: function (context, settings) {
      window.onAmazonLoginReady = function () {
        amazon.Login.setClientId(settings.AmazonLPA.clientId);
        amazon.Login.setUseCookie(true);
      };

      // @todo: Probably easier way to merge all these values.
      Drupal.AmazonLPA.merchantId = settings.AmazonLPA.merchantId;
      Drupal.AmazonLPA.clientId = settings.AmazonLPA.clientId;
      Drupal.AmazonLPA.checkoutUrl = settings.AmazonLPA.checkoutUrl;
      Drupal.AmazonLPA.langcode = settings.AmazonLPA.langcode;
      Drupal.AmazonLPA.orderReferenceId = settings.AmazonLPA.orderReferenceId || '';
      Drupal.AmazonLPA.loginOptions.popup = settings.AmazonLPA.popup || false;
      Drupal.AmazonLPA.loginButtonOptions.size = settings.AmazonLPA.buttonOptions.loginSize;
      Drupal.AmazonLPA.loginButtonOptions.style = settings.AmazonLPA.buttonOptions.loginStyle;
      Drupal.AmazonLPA.payButtonOptions.size = settings.AmazonLPA.buttonOptions.paySize;
      Drupal.AmazonLPA.payButtonOptions.style = settings.AmazonLPA.buttonOptions.payStyle;
      Drupal.AmazonLPA.payButtonOptions.type = settings.AmazonLPA.buttonOptions.payType;
      Drupal.AmazonLPA.addressBookOptions.displayMode = settings.AmazonLPA.addressBookOptions.displayMode;
      Drupal.AmazonLPA.walletOptions.displayMode = settings.AmazonLPA.walletOptions.displayMode;

      // Inject Widget.js
      var ws = document.createElement('script');
      ws.type = 'text/javascript';
      ws.src = settings.AmazonLPA.widgetsJsUrl;
      ws.id = 'AmazonLPAWidgets';
      ws.async = true;
      ws.onload = function () {
        if (typeof settings.AmazonLPA.callbacks === 'object') {
          for (var item in settings.AmazonLPA.callbacks) {
            if (typeof eval(settings.AmazonLPA.callbacks[item].callback) === 'function') {
              eval(settings.AmazonLPA.callbacks[item].callback)(settings.AmazonLPA.callbacks[item].param);
            }
          }
        }
      };
      document.getElementsByTagName('head')[0].appendChild(ws);
    }
  };

})(jQuery, window.Drupal, document);
